TextDecorationInset

Struct TextDecorationInset 

pub struct TextDecorationInset {
    pub start: LengthPercentage,
    pub end: LengthPercentage,
    pub is_auto: bool,
}
A text-decoration-inset value for animation: we resolve auto to a pair of lengths, but record whether the original value was actually auto.

Fields

start: LengthPercentage

The inset at the start of the decoration.

end: LengthPercentage

The inset at the end of the decoration.

is_auto: bool

Whether this represents a resolved auto value.